import { GraphQLResolveInfo, GraphQLScalarType, GraphQLScalarTypeConfig } from 'graphql';
import { MyContext } from '../context';
export declare type Maybe<T> = T | null;
export declare type Exact<T extends {
    [key: string]: unknown;
}> = {
    [K in keyof T]: T[K];
};
export declare type MakeOptional<T, K extends keyof T> = Omit<T, K> & {
    [SubKey in K]?: Maybe<T[SubKey]>;
};
export declare type MakeMaybe<T, K extends keyof T> = Omit<T, K> & {
    [SubKey in K]: Maybe<T[SubKey]>;
};
export declare type RequireFields<T, K extends keyof T> = {
    [X in Exclude<keyof T, K>]?: T[X];
} & {
    [P in K]-?: NonNullable<T[P]>;
};
/** All built-in and custom scalars, mapped to their actual values */
export declare type Scalars = {
    ID: string;
    String: string;
    Boolean: boolean;
    Int: number;
    Float: number;
    AnyObject: any;
    Date: any;
    DateTime: any;
    JSON: any;
    JSONObject: any;
    Observable: any;
    Time: any;
    URI: any;
    URIInput: any;
};
export declare type IAdminIdeSettings = {
    dummy?: Maybe<Scalars['Int']>;
};
export declare const enum ICacheControlScope {
    Public = "PUBLIC",
    Private = "PRIVATE"
}
/** Represents a null return value. */
export declare type IEmptyResponse = {
    alwaysNil?: Maybe<Scalars['String']>;
};
export declare type IFieldError = {
    field: Scalars['String'];
    message: Scalars['String'];
};
export declare type IGeoLocation = {
    type?: Maybe<Scalars['String']>;
    coordinates?: Maybe<Array<Maybe<Scalars['Float']>>>;
};
/**
 * Input geometry of the location.
 * List the `longitude` first and then `latitude`
 *  - Validate longitude values are between `-180` and `180`
 *  - Validate latitude values are between `-90` and `90`
 */
export declare type IGeoLocationInput = {
    type?: Maybe<Scalars['String']>;
    coordinates?: Maybe<Array<Maybe<Scalars['Float']>>>;
};
export declare type IIKubectlLogSettings = {
    subTopic?: Maybe<Scalars['String']>;
};
export declare type IIResourceUtilizationSettings = {
    subTopic?: Maybe<Scalars['String']>;
    adminApiNamespace?: Maybe<Scalars['String']>;
};
export declare const enum IKubectlCmd {
    Stern = "stern",
    Kubectl = "kubectl"
}
export declare const enum IKubectlCmdFlags {
    Label = "LABEL",
    Tail = "TAIL",
    Stream = "STREAM",
    Namespace = "NAMESPACE",
    Container = "CONTAINER",
    Timestamps = "TIMESTAMPS"
}
export declare type IKubectlLogGetRequest = {
    labelKey: Scalars['String'];
    labelValue: Scalars['String'];
    nameSpace: Scalars['String'];
    tail?: Maybe<Scalars['Int']>;
    stream?: Maybe<Scalars['Boolean']>;
    timeStamp?: Maybe<Scalars['Boolean']>;
};
export declare type IKubectlLogSettings = IIKubectlLogSettings & {
    subTopic?: Maybe<Scalars['String']>;
};
export declare type IKubectlLoggerService = {
    getLogs?: Maybe<Scalars['AnyObject']>;
};
export declare type IKubectlLoggerServiceGetLogsArgs = {
    logRequest?: Maybe<IKubectlLogGetRequest>;
};
export declare const enum IKubectlLoggerServiceAction {
    Stream = "stream"
}
export declare const enum IMailTemplateId {
    Dummy = "dummy"
}
export declare const enum IMoleculerCronServiceName {
    Dummy = "dummy"
}
/**  All Moleculer Topic names are extended from this. */
export declare const enum IMoleculerServiceName {
    KubectlLoggerService = "KubectlLoggerService",
    Dummy = "dummy"
}
export declare type IMutation = {
    dummy?: Maybe<Scalars['Int']>;
};
/** An object with an ID. */
export declare type INode = {
    /** The ID of the node. */
    id: Scalars['ID'];
};
export declare type IPageInfo = {
    hasNextPage: Scalars['Boolean'];
};
export declare type IQuery = {
    /** Looks up a node by ID. */
    node?: Maybe<INode>;
};
export declare type IQueryNodeArgs = {
    id: Scalars['ID'];
};
export declare type ISort = {
    key: Scalars['String'];
    value: ISortEnum;
};
export declare const enum ISortEnum {
    Asc = "ASC",
    Desc = "DESC"
}
export declare const enum ISternCmdFlags {
    Label = "LABEL",
    Namespace = "NAMESPACE",
    Timestamps = "TIMESTAMPS",
    Tail = "TAIL",
    Container = "CONTAINER"
}
export declare type ISubscription = {
    dummy?: Maybe<Scalars['Int']>;
};
export declare type ResolverTypeWrapper<T> = Promise<T> | T;
export declare type ResolverWithResolve<TResult, TParent, TContext, TArgs> = {
    resolve: ResolverFn<TResult, TParent, TContext, TArgs>;
};
export declare type LegacyStitchingResolver<TResult, TParent, TContext, TArgs> = {
    fragment: string;
    resolve: ResolverFn<TResult, TParent, TContext, TArgs>;
};
export declare type NewStitchingResolver<TResult, TParent, TContext, TArgs> = {
    selectionSet: string;
    resolve: ResolverFn<TResult, TParent, TContext, TArgs>;
};
export declare type StitchingResolver<TResult, TParent, TContext, TArgs> = LegacyStitchingResolver<TResult, TParent, TContext, TArgs> | NewStitchingResolver<TResult, TParent, TContext, TArgs>;
export declare type Resolver<TResult, TParent = {}, TContext = {}, TArgs = {}> = ResolverFn<TResult, TParent, TContext, TArgs> | ResolverWithResolve<TResult, TParent, TContext, TArgs> | StitchingResolver<TResult, TParent, TContext, TArgs>;
export declare type ResolverFn<TResult, TParent, TContext, TArgs> = (parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => Promise<TResult> | TResult;
export declare type SubscriptionSubscribeFn<TResult, TParent, TContext, TArgs> = (parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => AsyncIterator<TResult> | Promise<AsyncIterator<TResult>>;
export declare type SubscriptionResolveFn<TResult, TParent, TContext, TArgs> = (parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => TResult | Promise<TResult>;
export interface SubscriptionSubscriberObject<TResult, TKey extends string, TParent, TContext, TArgs> {
    subscribe: SubscriptionSubscribeFn<{
        [key in TKey]: TResult;
    }, TParent, TContext, TArgs>;
    resolve?: SubscriptionResolveFn<TResult, {
        [key in TKey]: TResult;
    }, TContext, TArgs>;
}
export interface SubscriptionResolverObject<TResult, TParent, TContext, TArgs> {
    subscribe: SubscriptionSubscribeFn<any, TParent, TContext, TArgs>;
    resolve: SubscriptionResolveFn<TResult, any, TContext, TArgs>;
}
export declare type SubscriptionObject<TResult, TKey extends string, TParent, TContext, TArgs> = SubscriptionSubscriberObject<TResult, TKey, TParent, TContext, TArgs> | SubscriptionResolverObject<TResult, TParent, TContext, TArgs>;
export declare type SubscriptionResolver<TResult, TKey extends string, TParent = {}, TContext = {}, TArgs = {}> = ((...args: any[]) => SubscriptionObject<TResult, TKey, TParent, TContext, TArgs>) | SubscriptionObject<TResult, TKey, TParent, TContext, TArgs>;
export declare type TypeResolveFn<TTypes, TParent = {}, TContext = {}> = (parent: TParent, context: TContext, info: GraphQLResolveInfo) => Maybe<TTypes> | Promise<Maybe<TTypes>>;
export declare type IsTypeOfResolverFn<T = {}, TContext = {}> = (obj: T, context: TContext, info: GraphQLResolveInfo) => boolean | Promise<boolean>;
export declare type NextResolverFn<T> = () => Promise<T>;
export declare type DirectiveResolverFn<TResult = {}, TParent = {}, TContext = {}, TArgs = {}> = (next: NextResolverFn<TResult>, parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => TResult | Promise<TResult>;
/** Mapping between all available schema types and the resolvers types */
export declare type IResolversTypes = {
    AdminIdeSettings: ResolverTypeWrapper<IAdminIdeSettings>;
    Int: ResolverTypeWrapper<Scalars['Int']>;
    AnyObject: ResolverTypeWrapper<Scalars['AnyObject']>;
    CacheControlScope: ICacheControlScope;
    Date: ResolverTypeWrapper<Scalars['Date']>;
    DateTime: ResolverTypeWrapper<Scalars['DateTime']>;
    EmptyResponse: ResolverTypeWrapper<IEmptyResponse>;
    String: ResolverTypeWrapper<Scalars['String']>;
    FieldError: ResolverTypeWrapper<IFieldError>;
    GeoLocation: ResolverTypeWrapper<IGeoLocation>;
    Float: ResolverTypeWrapper<Scalars['Float']>;
    GeoLocationInput: IGeoLocationInput;
    IKubectlLogSettings: IResolversTypes['KubectlLogSettings'];
    IResourceUtilizationSettings: never;
    JSON: ResolverTypeWrapper<Scalars['JSON']>;
    JSONObject: ResolverTypeWrapper<Scalars['JSONObject']>;
    KubectlCmd: IKubectlCmd;
    KubectlCmdFlags: IKubectlCmdFlags;
    KubectlLogGetRequest: ResolverTypeWrapper<IKubectlLogGetRequest>;
    Boolean: ResolverTypeWrapper<Scalars['Boolean']>;
    KubectlLogSettings: ResolverTypeWrapper<IKubectlLogSettings>;
    KubectlLoggerService: ResolverTypeWrapper<IKubectlLoggerService>;
    KubectlLoggerServiceAction: IKubectlLoggerServiceAction;
    MailTemplateId: IMailTemplateId;
    MoleculerCronServiceName: IMoleculerCronServiceName;
    MoleculerServiceName: IMoleculerServiceName;
    Mutation: ResolverTypeWrapper<{}>;
    Node: never;
    ID: ResolverTypeWrapper<Scalars['ID']>;
    Observable: ResolverTypeWrapper<Scalars['Observable']>;
    PageInfo: ResolverTypeWrapper<IPageInfo>;
    Query: ResolverTypeWrapper<{}>;
    Sort: ISort;
    SortEnum: ISortEnum;
    SternCmdFlags: ISternCmdFlags;
    Subscription: ResolverTypeWrapper<{}>;
    Time: ResolverTypeWrapper<Scalars['Time']>;
    URI: ResolverTypeWrapper<Scalars['URI']>;
    URIInput: ResolverTypeWrapper<Scalars['URIInput']>;
};
/** Mapping between all available schema types and the resolvers parents */
export declare type IResolversParentTypes = {
    AdminIdeSettings: IAdminIdeSettings;
    Int: Scalars['Int'];
    AnyObject: Scalars['AnyObject'];
    Date: Scalars['Date'];
    DateTime: Scalars['DateTime'];
    EmptyResponse: IEmptyResponse;
    String: Scalars['String'];
    FieldError: IFieldError;
    GeoLocation: IGeoLocation;
    Float: Scalars['Float'];
    GeoLocationInput: IGeoLocationInput;
    IKubectlLogSettings: IResolversParentTypes['KubectlLogSettings'];
    IResourceUtilizationSettings: never;
    JSON: Scalars['JSON'];
    JSONObject: Scalars['JSONObject'];
    KubectlLogGetRequest: IKubectlLogGetRequest;
    Boolean: Scalars['Boolean'];
    KubectlLogSettings: IKubectlLogSettings;
    KubectlLoggerService: IKubectlLoggerService;
    Mutation: {};
    Node: never;
    ID: Scalars['ID'];
    Observable: Scalars['Observable'];
    PageInfo: IPageInfo;
    Query: {};
    Sort: ISort;
    Subscription: {};
    Time: Scalars['Time'];
    URI: Scalars['URI'];
    URIInput: Scalars['URIInput'];
};
export declare type ICacheControlDirectiveArgs = {
    maxAge?: Maybe<Scalars['Int']>;
    scope?: Maybe<ICacheControlScope>;
};
export declare type ICacheControlDirectiveResolver<Result, Parent, ContextType = MyContext, Args = ICacheControlDirectiveArgs> = DirectiveResolverFn<Result, Parent, ContextType, Args>;
export declare type IAdminIdeSettingsResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['AdminIdeSettings'] = IResolversParentTypes['AdminIdeSettings']> = {
    dummy?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export interface IAnyObjectScalarConfig extends GraphQLScalarTypeConfig<IResolversTypes['AnyObject'], any> {
    name: 'AnyObject';
}
export interface IDateScalarConfig extends GraphQLScalarTypeConfig<IResolversTypes['Date'], any> {
    name: 'Date';
}
export interface IDateTimeScalarConfig extends GraphQLScalarTypeConfig<IResolversTypes['DateTime'], any> {
    name: 'DateTime';
}
export declare type IEmptyResponseResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['EmptyResponse'] = IResolversParentTypes['EmptyResponse']> = {
    alwaysNil?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IFieldErrorResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['FieldError'] = IResolversParentTypes['FieldError']> = {
    field?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    message?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IGeoLocationResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['GeoLocation'] = IResolversParentTypes['GeoLocation']> = {
    type?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    coordinates?: Resolver<Maybe<Array<Maybe<IResolversTypes['Float']>>>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IIKubectlLogSettingsResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['IKubectlLogSettings'] = IResolversParentTypes['IKubectlLogSettings']> = {
    __resolveType: TypeResolveFn<'KubectlLogSettings', ParentType, ContextType>;
    subTopic?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
};
export declare type IIResourceUtilizationSettingsResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['IResourceUtilizationSettings'] = IResolversParentTypes['IResourceUtilizationSettings']> = {
    __resolveType: TypeResolveFn<null, ParentType, ContextType>;
    subTopic?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    adminApiNamespace?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
};
export interface IJsonScalarConfig extends GraphQLScalarTypeConfig<IResolversTypes['JSON'], any> {
    name: 'JSON';
}
export interface IJsonObjectScalarConfig extends GraphQLScalarTypeConfig<IResolversTypes['JSONObject'], any> {
    name: 'JSONObject';
}
export declare type IKubectlLogGetRequestResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['KubectlLogGetRequest'] = IResolversParentTypes['KubectlLogGetRequest']> = {
    labelKey?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    labelValue?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    nameSpace?: Resolver<IResolversTypes['String'], ParentType, ContextType>;
    tail?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
    stream?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    timeStamp?: Resolver<Maybe<IResolversTypes['Boolean']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IKubectlLogSettingsResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['KubectlLogSettings'] = IResolversParentTypes['KubectlLogSettings']> = {
    subTopic?: Resolver<Maybe<IResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IKubectlLoggerServiceResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['KubectlLoggerService'] = IResolversParentTypes['KubectlLoggerService']> = {
    getLogs?: Resolver<Maybe<IResolversTypes['AnyObject']>, ParentType, ContextType, RequireFields<IKubectlLoggerServiceGetLogsArgs, never>>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IMutationResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['Mutation'] = IResolversParentTypes['Mutation']> = {
    dummy?: Resolver<Maybe<IResolversTypes['Int']>, ParentType, ContextType>;
};
export declare type INodeResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['Node'] = IResolversParentTypes['Node']> = {
    __resolveType: TypeResolveFn<null, ParentType, ContextType>;
    id?: Resolver<IResolversTypes['ID'], ParentType, ContextType>;
};
export interface IObservableScalarConfig extends GraphQLScalarTypeConfig<IResolversTypes['Observable'], any> {
    name: 'Observable';
}
export declare type IPageInfoResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['PageInfo'] = IResolversParentTypes['PageInfo']> = {
    hasNextPage?: Resolver<IResolversTypes['Boolean'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
};
export declare type IQueryResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['Query'] = IResolversParentTypes['Query']> = {
    node?: Resolver<Maybe<IResolversTypes['Node']>, ParentType, ContextType, RequireFields<IQueryNodeArgs, 'id'>>;
};
export declare type ISubscriptionResolvers<ContextType = MyContext, ParentType extends IResolversParentTypes['Subscription'] = IResolversParentTypes['Subscription']> = {
    dummy?: SubscriptionResolver<Maybe<IResolversTypes['Int']>, "dummy", ParentType, ContextType>;
};
export interface ITimeScalarConfig extends GraphQLScalarTypeConfig<IResolversTypes['Time'], any> {
    name: 'Time';
}
export interface IUriScalarConfig extends GraphQLScalarTypeConfig<IResolversTypes['URI'], any> {
    name: 'URI';
}
export interface IUriInputScalarConfig extends GraphQLScalarTypeConfig<IResolversTypes['URIInput'], any> {
    name: 'URIInput';
}
export declare type IResolvers<ContextType = MyContext> = {
    AdminIdeSettings?: IAdminIdeSettingsResolvers<ContextType>;
    AnyObject?: GraphQLScalarType;
    Date?: GraphQLScalarType;
    DateTime?: GraphQLScalarType;
    EmptyResponse?: IEmptyResponseResolvers<ContextType>;
    FieldError?: IFieldErrorResolvers<ContextType>;
    GeoLocation?: IGeoLocationResolvers<ContextType>;
    IKubectlLogSettings?: IIKubectlLogSettingsResolvers<ContextType>;
    IResourceUtilizationSettings?: IIResourceUtilizationSettingsResolvers<ContextType>;
    JSON?: GraphQLScalarType;
    JSONObject?: GraphQLScalarType;
    KubectlLogGetRequest?: IKubectlLogGetRequestResolvers<ContextType>;
    KubectlLogSettings?: IKubectlLogSettingsResolvers<ContextType>;
    KubectlLoggerService?: IKubectlLoggerServiceResolvers<ContextType>;
    Mutation?: IMutationResolvers<ContextType>;
    Node?: INodeResolvers<ContextType>;
    Observable?: GraphQLScalarType;
    PageInfo?: IPageInfoResolvers<ContextType>;
    Query?: IQueryResolvers<ContextType>;
    Subscription?: ISubscriptionResolvers<ContextType>;
    Time?: GraphQLScalarType;
    URI?: GraphQLScalarType;
    URIInput?: GraphQLScalarType;
};
export declare type IDirectiveResolvers<ContextType = MyContext> = {
    cacheControl?: ICacheControlDirectiveResolver<any, any, ContextType>;
};
